@@ -6,3 +6,5 @@ pub use crate::json::{Json, DEFAULT_JSON_LIMIT};
 pub use crate::lazy_data::LazyData;
 pub use crate::path::Path;
 pub use crate::query::Query;
+#[doc(hidden)]
+pub use crate::request_hash::{RequestHash, RequestHasher};
